/**
 * EasyBeans
 * Copyright (C) 2006 Bull S.A.S.
 * Contact: easybeans@ow2.org
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307
 * USA
 *
 * --------------------------------------------------------------------------
 * $Id: StatelessBean.java 5369 2010-02-24 14:58:19Z benoitf $
 * --------------------------------------------------------------------------
 */

package org.ow2.easybeans.examples.security;

import javax.annotation.Resource;
import javax.annotation.security.DeclareRoles;
import javax.annotation.security.DenyAll;
import javax.annotation.security.PermitAll;
import javax.annotation.security.RolesAllowed;
import javax.ejb.EJB;
import javax.ejb.Remote;
import javax.ejb.SessionContext;
import javax.ejb.Stateless;

/**
 * Stateless Bean with secured methods.
 * Two roles are declared : user and admin.
 * @author Florent Benoit
 */
@Stateless(mappedName="securityBean")
@Remote(StatelessRemote.class)
@DeclareRoles({"user", "admin"})
public class StatelessBean implements StatelessRemote {

    /**
     * SessionContext used to get current caller.
     */
    @Resource
    private SessionContext sessionContext;

    /**
     * Link to run-as bean.
     */
    @EJB
    private StatelessRunAsRemote other;

    /**
     * Method can be called by some roles.
     */
    @RolesAllowed({"user", "admin"})
    public void someRolesAllowed() {
        System.out.println("someRolesAllowed() called");
        printCurrentCaller();
    }

    /**
     * Method can be called by all security roles.
     */
    @PermitAll
    public void allRolesAllowed() {
        System.out.println("someRolesAllowed() called");
        printCurrentCaller();
        System.out.print("for run-as bean, caller is ");
        other.printCurrentCaller();
    }

    /**
     * Only "admin" role can invoke this method.
     */
    @RolesAllowed("admin")
    public void onlyAdminAllowed() {
        System.out.println("onlyAdminAllowed() called");
        printCurrentCaller();
    }

    /**
     * No role can invoke this method.
     */
    @DenyAll
    public void deniedForAll() {
        // nothing as it can't be called
        throw new RuntimeException("Method denied, should not be called");
    }


    /**
     * Prints the current caller.
     */
    public void printCurrentCaller() {
        System.out.println("-> Caller is '" + sessionContext.getCallerPrincipal() + "'.");
    }

    /**
     * Make a call on a run-as bean which call our bean after that..
     */
    public void callRunAsBean() {
        other.callBeanWithRunAsAdmin();
    }
}
